-- Dynamic Scenario City Names
-- Author: FramedArchitecture
-- DateCreated: 1/2013
--------------------------------------------------------------
function OnScenarioCityCreated( iPlayer, iX, iY )
    local city = Map.GetPlot(iX, iY):GetPlotCity()
    local nameKey = GetScenarioCityTxtKey(iPlayer, iX, iY)
    if nameKey then
       city:SetName(Locale.ConvertTextKey(nameKey))
    end
end
--------------------------------------------------------------
function OnScenarioCityCaptured (iOldOwner, bIsCapital, iX, iY, iNewOwner, iPop, bConquest)
    local city = Map.GetPlot(iX, iY):GetPlotCity()
    local nameKey = GetScenarioCityTxtKey(iNewOwner, iX, iY)
    if nameKey then
        city:SetName(Locale.ConvertTextKey(nameKey))
    end
end
--------------------------------------------------------------
function GetScenarioCityTxtKey(iPlayer, iX, iY)
    local cityNameKey = nil
    local CityNames = {}
    local pCivType = GameInfo.Civilizations[Players[iPlayer]:GetCivilizationType()].Type

    --print("GetScenarioCityTxtKey", pCivType, iX, iY)

    for row in GameInfo.Civilization_AE_CityNames("CivilizationType='" .. pCivType .. "'") do
        local plotDistance = Map.PlotDistance(iX, iY, row.CityX, row.CityY)
        if ( plotDistance <= row.CityRadius ) then
            local cNameKey = row.CityName
            if IsValidCityName(cNameKey) then
                table.insert(CityNames, {dist = plotDistance, name = cNameKey})
            end
        end
    end

	if (#CityNames == 0) then
		 for row in GameInfo.Civilization_AE_EuropeCityNames() do
			local plotDistance = Map.PlotDistance(iX, iY, row.CityX, row.CityY)
			if ( plotDistance <= row.CityRadius ) then
				local cNameKey = row.CityName
				if IsValidCityName(cNameKey) then
					table.insert(CityNames, {dist = plotDistance, name = cNameKey})
				end
			end
		end
	end

    if (#CityNames == 1) then
        cityNameKey = CityNames[1].name

    elseif (#CityNames > 1) then

        table.sort(CityNames, function(x,y) if (x.dist == y.dist) then return (x.name < y.name) else return (x.dist < y.dist) end end)
 
        local possibleCities = 0
        local minDist = CityNames[1].dist

        for _,cn in ipairs(CityNames) do
            if cn.dist == minDist then
                possibleCities = possibleCities + 1
            else
                break
            end
        end

        cityNameKey = CityNames[math.random(possibleCities)].name
	
    end

    return cityNameKey
end
--------------------------------------------------------------
function IsValidCityName(nameKey)
    local nameKey = Locale.ConvertTextKey(nameKey)
    for iPlayerLoop = 0, GameDefines.MAX_MAJOR_CIVS-1, 1 do
        local player = Players[iPlayerLoop]
        if player:IsAlive() then
            for city in player:Cities() do
                if nameKey == city:GetName() then
                    return false
                end
            end
        end
    end

    return true
end
--------------------------------------------------------------
local map = Path.GetFileNameWithoutExtension(PreGame.GetMapScript())
if string.match(string.sub(map, 1, 15), "ACCURATE_EUROPE_DOMINATION") then
	if Game.GetElapsedGameTurns() == 0 then
		for playerID = 0, GameDefines.MAX_CIV_PLAYERS-1, 1 do
			local player = Players[playerID]
			if player and player:IsAlive() then
				for city in player:Cities() do
				   OnScenarioCityCreated( playerID, city:GetX(), city:GetY() )
				end
			end
		end
	end

	GameEvents.PlayerCityFounded.Add( OnScenarioCityCreated )
	GameEvents.CityCaptureComplete.Add( OnScenarioCityCaptured )

	print("City names initialized")
end
--------------------------------------------------------------