--------------------------------------------------------------------------------------------------
-- Worlds
-------------------------------------------------------------------------------------------------- 
UPDATE Worlds SET MaxActiveReligions = 9		WHERE Type LIKE 'WORLDSIZE_%';

--------------------------------------------------------------------------------------------------
-- Defines
-------------------------------------------------------------------------------------------------- 
UPDATE Defines SET Value = 2		WHERE Name = 'RELIGION_GAME_FAITH_DELTA_NEXT_PANTHEON';
--UPDATE Defines SET Value = 2		WHERE Name = 'MIN_CITY_RANGE';

--------------------------------------------------------------------------------------------------
--Terrains
--------------------------------------------------------------------------------------------------
UPDATE Terrains SET Found = 0 WHERE Type IN ( 'TERRAIN_DESERT', 'TERRAIN_SNOW' );
UPDATE Terrain_Yields SET Yield = 0 WHERE TerrainType = 'TERRAIN_TUNDRA' AND YieldType = 'YIELD_FOOD';
UPDATE Terrain_HillsYieldChanges SET Yield = -1 WHERE TerrainType = 'TERRAIN_GRASS' AND YieldType = 'YIELD_FOOD';
UPDATE Terrain_HillsYieldChanges SET Yield = 1 WHERE TerrainType = 'TERRAIN_GRASS' AND YieldType = 'YIELD_PRODUCTION';

UPDATE Features SET NoCity = 1 WHERE Type = 'FEATURE_MARSH';
UPDATE Features SET AddsFreshWater = 0 WHERE Type = 'FEATURE_OASIS';

INSERT INTO Improvement_Yields (ImprovementType,	YieldType,				Yield)
SELECT 'IMPROVEMENT_CITADEL',						'YIELD_FOOD',			-2 UNION ALL
SELECT 'IMPROVEMENT_CITADEL',						'YIELD_PRODUCTION',		2 UNION ALL
SELECT 'IMPROVEMENT_CITADEL',						'YIELD_GOLD',			2;

INSERT INTO Improvement_RiverSideYields (ImprovementType,	YieldType,		Yield)
SELECT 'IMPROVEMENT_TRADING_POST',							'YIELD_GOLD',	1;

DELETE FROM Improvement_ValidTerrains WHERE ImprovementType = 'IMPROVEMENT_TRADING_POST' AND TerrainType = 'TERRAIN_DESERT';
DELETE FROM Improvement_ValidTerrains WHERE ImprovementType = 'IMPROVEMENT_FARM' AND TerrainType = 'TERRAIN_DESERT';

--------------------------------------------------------------------------------------------------
--Buildings
--------------------------------------------------------------------------------------------------
INSERT INTO BuildingClasses (Type,		DefaultBuilding,		MaxPlayerInstances,	Description)
SELECT 'BUILDINGCLASS_CHURCH',			'BUILDING_CHURCH',		-1,					'TXT_KEY_BUILDING_STAVE_CHURCH';

INSERT INTO Buildings (Type,	BuildingClass,				Cost,	FaithCost,	UnlockedByBelief,	ConquestProb,	Happiness,	IconAtlas,							PortraitIndex,	Description,						Help,										Strategy,										Civilopedia,									ArtDefineTag,	MinAreaSize) 
SELECT 'BUILDING_CHURCH',		'BUILDINGCLASS_CHURCH',		-1,		200,		1,					100,			1,			'EXPANSION_SCEN_BUILDING_ATLAS',	0,				'TXT_KEY_BUILDING_STAVE_CHURCH',	'TXT_KEY_BUILDING_STAVE_CHURCH_STRATEGY',	'TXT_KEY_BUILDING_STAVE_CHURCH_STRATEGY',		'TXT_KEY_CIV5_BUILDINGS_STAVE_CHURCH_TEXT',		'TEMPLE',		-1;

DELETE FROM Buildings WHERE Type IN ('BUILDING_GREAT_WALL', 'BUILDING_ANGKOR_WAT', 'BUILDING_CHICHEN_ITZA', 'BUILDING_MACHU_PICHU', 'BUILDING_PORCELAIN_TOWER', 'BUILDING_HIMEJI_CASTLE', 'BUILDING_FORBIDDEN_PALACE', 'BUILDING_TAJ_MAHAL', 'BUILDING_CRISTO_REDENTOR', 'BUILDING_BOROBUDUR', 'BUILDING_TERRACOTTA_ARMY');

--------------------------------------------------------------------------------------------------
--Building Yield Changes
--------------------------------------------------------------------------------------------------
INSERT INTO Building_YieldChanges (BuildingType,	YieldType,				Yield)
SELECT 'BUILDING_CASTLE',							'YIELD_PRODUCTION',		1 UNION ALL
SELECT 'BUILDING_CASTLE',							'YIELD_GOLD',			2 UNION ALL
SELECT 'BUILDING_WALLS',							'YIELD_PRODUCTION',		1 UNION ALL
SELECT 'BUILDING_CHURCH',							'YIELD_FAITH',			2 UNION ALL
SELECT 'BUILDING_CHURCH',							'YIELD_PRODUCTION',		1 UNION ALL
SELECT 'BUILDING_CHURCH',							'YIELD_GOLD',			1;

--------------------------------------------------------------------------------------------------
--Building Flavors
--------------------------------------------------------------------------------------------------
INSERT INTO Building_Flavors (BuildingType,		FlavorType,					Flavor)
SELECT 'BUILDING_CASTLE',						'FLAVOR_PRODUCTION',		4 UNION ALL
SELECT 'BUILDING_CASTLE',						'FLAVOR_GOLD',				4 UNION ALL
SELECT 'BUILDING_WALLS',						'FLAVOR_PRODUCTION',		2 UNION ALL
SELECT 'BUILDING_CHURCH',						'FLAVOR_RELIGION',			2 UNION ALL
SELECT 'BUILDING_CHURCH',						'FLAVOR_PRODUCTION',		2 UNION ALL
SELECT 'BUILDING_CHURCH',						'FLAVOR_GOLD',				4 UNION ALL
SELECT 'BUILDING_CHURCH',						'FLAVOR_HAPPINESS',			3;

--------------------------------------------------------------------------------------------------
--Beliefs
--------------------------------------------------------------------------------------------------
UPDATE Beliefs SET SpreadStrengthModifier = 15 WHERE Type = 'BELIEF_RELIGIOUS_TEXTS';
UPDATE Beliefs SET SpreadDistanceModifier = 5 WHERE Type = 'BELIEF_ITINERANT_PREACHERS';

INSERT INTO Beliefs (Type,	Follower,	Description,				ShortDescription)
SELECT 'BELIEF_CHURCH',		1,			'TXT_KEY_BELIEF_CHURCH',	'TXT_KEY_BELIEF_CHURCH_SHORT';

INSERT INTO Belief_BuildingClassFaithPurchase (BeliefType,	BuildingClassType)
SELECT 'BELIEF_CHURCH',										'BUILDINGCLASS_CHURCH';

--------------------------------------------------------------------------------------------------
--Units
--------------------------------------------------------------------------------------------------
UPDATE Units SET RivalTerritory = 1 WHERE Type IN ('UNIT_SCOUT', 'UNIT_CARAVEL', 'UNIT_PORTUGUESE_NAU', 'UNIT_DUTCH_SEA_BEGGAR');

--------------------------------------------------------------------------------------------------
--Civilizations
--------------------------------------------------------------------------------------------------